@@ -1,16 +1,18 @@
+# pylint: disable=unused-argument
+
 import os
 import sys
 import time
 from contextlib import contextmanager
+from unittest import mock
 
+import pytest
 from click.testing import CliRunner
 from dagster import check
-from dagster.seven import mock
+from dagster.core.test_utils import instance_for_test
 from dagster.utils import file_relative_path
 from dagster_celery.cli import main
 
-from .utils import skip_ci
-
 
 def assert_called(mck):
     if hasattr(mck, "assert_called"):
@@ -43,7 +45,8 @@ def start_worker(name, args=None, exit_code=0, exception_str=""):
     args = check.opt_list_param(args, "args")
     runner = CliRunner()
     result = runner.invoke(
-        main, ["worker", "start", "-A", "dagster_celery.app", "-d"] + args + ["--name", name]
+        main,
+        ["worker", "start", "-A", "dagster_celery.app", "-d", "--name", name] + args,
     )
     assert result.exit_code == exit_code, str(result.exception)
     if exception_str:
@@ -57,7 +60,7 @@ def cleanup_worker(name, args=None):
         yield
     finally:
         runner = CliRunner()
-        result = runner.invoke(main, ["worker", "terminate"] + args + [name])
+        result = runner.invoke(main, ["worker", "terminate", name] + args)
         assert result.exit_code == 0, str(result.exception)
 
 
@@ -95,15 +98,17 @@ def test_invoke_entrypoint():
     assert "Start a dagster celery worker" in result.output
 
 
-@skip_ci
-def test_start_worker():
+# https://github.com/dagster-io/dagster/issues/3494
+@pytest.mark.skip
+def test_start_worker(rabbitmq):
     with cleanup_worker("dagster_test_worker"):
         start_worker("dagster_test_worker")
         assert check_for_worker("dagster_test_worker")
 
 
-@skip_ci
-def test_start_worker_too_many_queues():
+# https://github.com/dagster-io/dagster/issues/3494
+@pytest.mark.skip
+def test_start_worker_too_many_queues(rabbitmq):
     args = ["-q", "1", "-q", "2", "-q", "3", "-q", "4", "-q", "5"]
 
     with cleanup_worker("dagster_test_worker"):
@@ -118,73 +123,81 @@ def test_start_worker_too_many_queues():
         )
 
 
-@skip_ci
-def test_start_worker_addargs():
-    args = ["--", "-uid", "42"]
+# https://github.com/dagster-io/dagster/issues/3494
+@pytest.mark.skip
+def test_start_worker_addargs(rabbitmq):
+    args = ["--", "--uid", "42"]
 
+    # Omitting check that uid is actually 42 to avoid a heavy test dependency on psutil
     with cleanup_worker("dagster_test_worker"):
         start_worker(
-            "dagster_test_worker", args=args,
+            "dagster_test_worker",
+            args=args,
         )
 
-        # Omitting to incur a heavy test dependency on psutil
 
-
-@skip_ci
-def test_start_worker_config_from_empty_yaml():
+# https://github.com/dagster-io/dagster/issues/3494
+@pytest.mark.skip
+def test_start_worker_config_from_empty_yaml(rabbitmq):
     args = ["-y", file_relative_path(__file__, "empty.yaml")]
     with cleanup_worker("dagster_test_worker", args=args):
         start_worker("dagster_test_worker", args=args)
-        assert check_for_worker("dagster_test_worker")
+        assert check_for_worker("dagster_test_worker", args=args)
 
 
-@skip_ci
-def test_start_worker_config_from_partial_yaml():
+# https://github.com/dagster-io/dagster/issues/3494
+@pytest.mark.skip
+def test_start_worker_config_from_partial_yaml(rabbitmq):
     args = ["-y", file_relative_path(__file__, "partial.yaml")]
     with cleanup_worker("dagster_test_worker", args=args):
         start_worker("dagster_test_worker", args=args)
-        assert check_for_worker("dagster_test_worker")
+        assert check_for_worker("dagster_test_worker", args=args)
 
 
-@skip_ci
-def test_start_worker_config_from_yaml():
+# https://github.com/dagster-io/dagster/issues/3494
+@pytest.mark.skip
+def test_start_worker_config_from_yaml(rabbitmq):
     args = ["-y", file_relative_path(__file__, "engine_config.yaml")]
 
     with cleanup_worker("dagster_test_worker", args=args):
         start_worker("dagster_test_worker", args=args)
-        assert check_for_worker("dagster_test_worker")
+        assert check_for_worker("dagster_test_worker", args=args)
 
 
 @mock.patch("dagster_celery.cli.launch_background_worker")
 def test_mock_start_worker(worker_patch):
-    start_worker("dagster_test_worker")
-    assert_called(worker_patch)
+    with instance_for_test():
+        start_worker("dagster_test_worker")
+        assert_called(worker_patch)
 
 
 @mock.patch("dagster_celery.cli.launch_background_worker")
 def test_mock_start_worker_config_from_empty_yaml(worker_patch):
-    args = ["-y", file_relative_path(__file__, "empty.yaml")]
-    start_worker("dagster_test_worker", args=args)
-    assert_called(worker_patch)
+    with instance_for_test():
+        args = ["-y", file_relative_path(__file__, "empty.yaml")]
+        start_worker("dagster_test_worker", args=args)
+        assert_called(worker_patch)
 
 
 @mock.patch("dagster_celery.cli.launch_background_worker")
 def test_start_mock_worker_config_from_yaml(worker_patch):
-    args = ["-y", file_relative_path(__file__, "engine_config.yaml")]
-    start_worker("dagster_test_worker", args=args)
-    assert_called(worker_patch)
+    with instance_for_test():
+        args = ["-y", file_relative_path(__file__, "engine_config.yaml")]
+        start_worker("dagster_test_worker", args=args)
+        assert_called(worker_patch)
 
 
 @mock.patch("dagster_celery.cli.launch_background_worker")
 def test_mock_start_worker_too_many_queues(_worker_patch):
-    args = ["-q", "1", "-q", "2", "-q", "3", "-q", "4", "-q", "5"]
+    with instance_for_test():
+        args = ["-q", "1", "-q", "2", "-q", "3", "-q", "4", "-q", "5"]
 
-    start_worker(
-        "dagster_test_worker",
-        args=args,
-        exit_code=1,
-        exception_str=(
-            "Can't start a dagster_celery worker that listens on more than four queues, due to a "
-            "bug in Celery 4."
-        ),
-    )
+        start_worker(
+            "dagster_test_worker",
+            args=args,
+            exit_code=1,
+            exception_str=(
+                "Can't start a dagster_celery worker that listens on more than four queues, due to a "
+                "bug in Celery 4."
+            ),
+        )
